Show maximum pixel error on equals().
[libdcp.git] / src / dcp.h
index b2d20c699d6d5548a75d8958dff7f51abba7c4d4..477c19011278fec98039663164649943875a620f 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
 
 */
 
+/** @file  src/dcp.h
+ *  @brief A class to create a DCP.
+ */
+
 #ifndef LIBDCP_DCP_H
 #define LIBDCP_DCP_H
 
 #include <string>
-#include <list>
+#include <vector>
 #include <boost/shared_ptr.hpp>
 #include <sigc++/sigc++.h>
+#include "types.h"
+
+namespace xmlpp {
+       class Node;
+}
 
 /** @brief Namespace for everything in libdcp */
 namespace libdcp
@@ -33,90 +42,72 @@ class Asset;
 
 /** @class DCP dcp.h libdcp/dcp.h
  *  @brief A class to create a DCP.
- *
- *  Typical use might be:
- *  @code
- *  #include <libdcp/dcp.h>
- *  using namespace std;
- *
- *  libdcp::DCP dcp ("My Film DCP", "My Film", libdcp::DCP::FEATURE, 24, 50000);
- *
- *  list<string> j2k_files;
- *  j2k_files.push_back ("1.j2c");
- *  ...
- *  j2k_files.push_back ("50000.j2c");
- *
- *  // These images are 1998x1080 pixels (DCI Flat)
- *  dcp.add_picture_asset (j2k_files, 1998, 1080);
- *
- *  list<string> wav_files;
- *  wav_files.push_back ("L.wav");
- *  wav_files.push_back ("R.wav");
- *  wav_files.push_back ("C.wav");
- *  wav_files.push_back ("Lfe.wav");
- *  wav_files.push_back ("Ls.wav");
- *  wav_files.push_back ("Rs.wav");
- *  dcp.add_sound_asset (wav_files);
- *
- *  dcp.write_xml ();
- *
- *  @endcode
- *
- *  This will create a DCP at 24 frames per second with 50000 frames, writing
- *  data to a directory "My Film DCP", naming the DCP "My Film" and marking
- *  as a Feature.  We then add the picture and sound files (which creates
- *  MXF files inside the DCP directory) and then write the required XML files.
- *
- *  If you want to report progress for long jobs (add_picture_asset() can
- *  take a long time, in particular, as it must do a lot of disk I/O for
- *  large DCPs), connect to the libdcp::DCP::Progress signal and report its parameter
- *  to the user (it will range between 0 for 0% and 1 for 100%).
  */
+       
 class DCP
 {
 public:
-       enum ContentType
-       {
-               FEATURE,
-               SHORT,
-               TRAILER,
-               TEST,
-               TRANSITIONAL,
-               RATING,
-               TEASER,
-               POLICY,
-               PUBLIC_SERVICE_ANNOUNCEMENT,
-               ADVERTISEMENT
-       };
-
        /** Construct a DCP.
         *  @param directory Directory to write files to.
         *  @param name Name.
-        *  @param content_type Content type.
+        *  @param content_kind Content kind.
         *  @param fps Frames per second.
         *  @param length Length in frames.
         */
-       DCP (std::string directory, std::string name, ContentType content_type, int fps, int length);
+       DCP (std::string directory, std::string name, ContentKind content_kind, int fps, int length);
+
+       DCP (std::string directory);
 
        /** Add a sound asset.
         *  @param files Pathnames of WAV files to use in the order Left, Right,
-        *  Centre, Lfe (sub), Left surround, Right surround.
+        *  Centre, Lfe (sub), Left surround, Right surround; not all files need
+        *  to be present.
+        */
+       void add_sound_asset (std::vector<std::string> const & files);
+
+       /** Add a sound asset.
+        *  @param get_path Functor to get the path to the WAV for a given channel.
+        *  @param channels Number of channels.
         */
-       void add_sound_asset (std::list<std::string> const & files);
+       void add_sound_asset (sigc::slot<std::string, Channel> get_path, int channels);
 
        /** Add a picture asset.
         *  @param files Pathnames of JPEG2000 files, in frame order.
         *  @param width Width of images in pixels.
         *  @param height Height of images in pixels.
         */
-       void add_picture_asset (std::list<std::string> const & files, int width, int height);
+       void add_picture_asset (std::vector<std::string> const & files, int width, int height);
+
+       /** Add a picture asset.
+        *  @param get_path Functor to get path to the JPEG2000 for a given frame.
+        *  @param width Width of images in pixels.
+        *  @param height Height of images in pixels.
+        */
+       void add_picture_asset (sigc::slot<std::string, int> get_path, int width, int height);
 
        /** Write the required XML files to the directory that was
         *  passed into the constructor.
         */
        void write_xml () const;
 
+       std::string name () const {
+               return _name;
+       }
+
+       ContentKind content_kind () const {
+               return _content_kind;
+       }
+
+       int frames_per_second () const {
+               return _fps;
+       }
+
+       int length () const {
+               return _length;
+       }
+
+       std::list<std::string> equals (DCP const & other, EqualityOptions options) const;
+
        /** Emitted with a parameter between 0 and 1 to indicate progress
         *  for long jobs.
         */
@@ -149,17 +140,12 @@ private:
         */
        void write_assetmap (std::string cpl_uuid, int cpl_length, std::string pkl_uuid, int pkl_length) const;
 
-       /** @param type A content type.
-        *  @return A string representation suitable for use in a CPL.
-        */
-       static std::string content_type_string (ContentType type);
-
        /** the directory that we are writing to */
        std::string _directory;
        /** the name of the DCP */
        std::string _name;
-       /** the content type of the DCP */
-       ContentType _content_type;
+       /** the content kind of the DCP */
+       ContentKind _content_kind;
        /** frames per second */
        int _fps;
        /** length in frames */